import Axios, { AxiosRequestConfig, AxiosResponse } from 'axios';
import { EmptyReq, LoginReq, RegisterReq, UserResponse } from './types';

type LoginQuery = (data?: LoginReq) => Promise<AxiosResponse<UserResponse>>;
type RegisterQuery = (data?: RegisterReq) => Promise<AxiosResponse<UserResponse>>;
type MeQuery = (data?: EmptyReq, authToken?: string) => Promise<AxiosResponse<UserResponse>>;

export type AuthClient = {
  login: LoginQuery;
  me: MeQuery;
  register: RegisterQuery;
};

export function auth(config: AxiosRequestConfig): AuthClient {
  const axios = Axios.create({
    ...config,
    baseURL: `${config.baseURL}/api/auth`,
  });

  const login: LoginQuery = (data?: LoginReq): Promise<AxiosResponse<UserResponse>> => {
    return axios.post<UserResponse>('/login', data);
  };

  const register: RegisterQuery = (data?: RegisterReq): Promise<AxiosResponse<UserResponse>> => {
    return axios.post<UserResponse>('/register', data);
  };

  const me: MeQuery = (
    data?: undefined,
    authToken?: string,
  ): Promise<AxiosResponse<UserResponse>> => {
    return axios.get<UserResponse>('/me', {
      headers: { Authorization: `Bearer ${authToken}` },
    });
  };

  return {
    login,
    register,
    me,
  };
}
